@@ -37,7 +37,7 @@ struct TORCH_HIP_CPP_API CUDAPluggableAllocatorDeleterContext {
   hipStream_t stream_{};
 };
 
-#if defined(TORCH_HIP_VERSION)
+#if defined(USE_ROCM)
 using streamType = c10::hip::HIPStream;
 #else
 using streamType = c10::hip::HIPStreamMasqueradingAsCUDA;
